@@ -93,11 +93,17 @@ class TaSignals:
         df['ema50'] = df[key].ewm(span=50, adjust=False).mean()
         df['ema100'] = df[key].ewm(span=100, adjust=False).mean()
         df['ema200'] = df[key].ewm(span=200, adjust=False).mean()
+        df['ema8_slope'] = df['ema8'].rolling(window=self.window).apply(self.get_slope, raw=True)
 
         data = {'ema20': df['ema20'].iloc[-1], 'ema50': df['ema50'].iloc[-1], 'ema100': df['ema100'].iloc[-1], 'ema200': df['ema200'].iloc[-1]}
         data = [
+            {'key': 'ema_8_dropping', 'value': 'EMA8 is dropping' if df['ema8_slope'].iloc[-1] < 0 else False},
+            {'key': 'ema_8_rising', 'value': 'EMA8 is rising' if df['ema8_slope'].iloc[-1] > 0 else False},
+            {'key': 'ema_8_above_ema_34', 'value': 'EMA8 Above EMA34' if df['ema8'].iloc[-1] > df['ema34'].iloc[-1] else False},
+            {'key': 'ema_34_above_ema_8', 'value': 'EMA34 Above EMA8' if df['ema34'].iloc[-1] > df['ema8'].iloc[-1] else False},
             {'key': 'above_ema_8', 'value': 'Above 8 period exponential moving average' if df[key].iloc[-1] > df['ema8'].iloc[-1] else False},
             {'key': 'above_ema_20', 'value': 'Above 20 period exponential moving average' if df[key].iloc[-1] > df['ema20'].iloc[-1] else False},
+            {'key': 'above_ema_34', 'value': 'Above 34 period exponential moving average' if df[key].iloc[-1] > df['ema34'].iloc[-1] else False},
             {'key': 'above_ema_50', 'value': 'Above 50 period exponential moving average' if df[key].iloc[-1] > df['ema50'].iloc[-1] else False},
             {'key': 'above_ema_100', 'value': 'Above 100 period exponential moving average' if df[key].iloc[-1] > df['ema100'].iloc[-1] else False},
             {'key': 'above_ema_200', 'value': 'Above 200 period exponential moving average' if df[key].iloc[-1] > df['ema200'].iloc[-1] else False},
